<?php
/**
 * GMapFactory application
 * 
 * @project     MapLab
 * @revision    $Id: structure.php,v 1.6 2002/08/08 03:06:50 bronsema Exp $
 * @purpose     This page verifies that the correct directory structure exists
 *              for the given project.
 * @author      William A. Bronsema, C.E.T. (bronsema@dmsolutions.ca)
 * @copyright
 * <b>Copyright (c) 2002, DM Solutions Group Inc.</b>
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

/*****************************************************************************
 * $Log: structure.php,v $
 * Revision 1.6  2002/08/08 03:06:50  bronsema
 * Updated to generic drawmap.php
 *
 * Revision 1.5  2002/06/28 03:15:36  bronsema
 * Updated to new session variable handler
 *
 * Revision 1.4  2002/06/13 14:13:53  sacha
 * Change copywrite msg
 *
 * Revision 1.3  2002/06/12 18:47:58  bronsema
 * Added grouped layer option for the legend
 *
 * Revision 1.2  2002/05/28 18:33:21  bronsema
 * Added queries
 *
 * Revision 1.1  2002/05/06 12:03:42  bronsema
 * Updated path information to reflect changes in application structure
 *
 * Revision 1.7  2002/05/01 19:15:59  bronsema
 * Updated index page to simplfy the interface
 *
 * Revision 1.6  2002/04/30 18:55:56  bronsema
 * Under construction
 *
 *****************************************************************************/

// set the scope of the log file
$oLog->setScope( "structure" );

// log start
$oLog->logFuncStart( LOG_QUIET, "Begin structure check." );

/* ============================================================================
 * Check for the apps directory.
 * ========================================================================= */
if ( !is_dir( $gszNewAppPath.$gszGMFAppFolderName."/" ) )
{
    // working directory does not exist so create it
    if ( !mkdir( $gszNewAppPath.$gszGMFAppFolderName."/", 0777 ) )
    {
        // give error message
        $oLog->error( ERR_CRITICAL, "Unable to create the apps ".
            "directory[".$gszNewAppPath.$gszGMFAppFolderName."/].  Please ".
            "ensure that the parent ".
            "directory exists and is not set to read-only." );
        
        // abort all processes
        die( "A critcal error occurred in the last process.  Check the log ".
                          "file[".$gszLogPath."gmapfactory.log] for details" );                                                
    }
    else
    {
        // log creation
        $oLog->log( LOG_QUIET, "Successfully created ".
                      "directory[".$gszNewAppPath.$gszGMFAppFolderName."/]." );
    }
}

/* ============================================================================
 * Check for the project directory.
 * ========================================================================= */
if ( !is_dir( $gszNewAppPath.$gszGMFProjFolderName."/" ) )
{
    // working directory does not exist so create it
    if ( !mkdir( $gszNewAppPath.$gszGMFProjFolderName."/", 0777 ) )
    {
        // give error message
        $oLog->error( ERR_CRITICAL, "Unable to create the apps ".
            "directory[".$gszNewAppPath.$gszGMFProjFolderName."/].  Please ".
            "ensure that the parent ".
            "directory exists and is not set to read-only." );
        
        // abort all processes
        die( "A critcal error occurred in the last process.  Check the log ".
                          "file[".$gszLogPath."gmapfactory.log] for details" );                                                
    }
    else
    {
        // log creation
        $oLog->log( LOG_QUIET, "Successfully created ".
                      "directory[".$gszNewAppPath.$gszGMFProjFolderName."/]." );
    }
}

/* ============================================================================
 * Update the app and proj variables.
 * ========================================================================= */
// concatenate the application path
$gszAppDir = $gszNewAppPath.$gszGMFAppFolderName."/".
                                            $http_form_vars["gszAppName"]."/";

// concatenate the projects path
$gszWorkingDir = $gszNewAppPath.$gszGMFProjFolderName."/".
                                            $http_form_vars["gszAppName"]."/";

/* ============================================================================
 * Check for the working directory.
 * ========================================================================= */
if ( !is_dir( $gszWorkingDir ) )
{
    // working directory does not exist so create it
    if ( !mkdir( $gszWorkingDir, 0777 ) )
    {
        // give error message
        $oLog->error( ERR_CRITICAL, "Unable to create the working ".
            "directory[$gszWorkingDir].  Please ensure that the parent ".
            "directory exists and is not set to read-only." );
        
        // abort all processes
        die( "A critcal error occurred in the last process.  Check the log ".
                            "file[".$gszLogPath."gmapfactory.log] for details" );                                                
    }
    else
    {
        // log creation
        $oLog->log( LOG_QUIET, "Successfully created ".
                                            "directory[$gszWorkingDir]." );
    }
}

/* ============================================================================
 * Check for the main application directory.
 * ========================================================================= */
if ( !is_dir( $gszAppDir ) )
{
    // create the directory and log
    mkdir( $gszAppDir, 0777 );
    $oLog->log( LOG_QUIET, "Successfully created ".
                        "directory[".$gszWorkingDir."]." );
}

/* ============================================================================
 * Check for the application's tmp directory.
 * ========================================================================= */
if ( !is_dir( $gszAppDir."/tmp/" ) )
{
    // create the directory and log
    mkdir( $gszAppDir."/tmp/", 0777 );
    $oLog->log( LOG_QUIET, "Successfully created ".
                   "directory[".$gszAppDir."/tmp/]." );
}

/* ============================================================================
 * Check for the application's ROSA directory.
 * ========================================================================= */
if ( !is_dir( $gszAppDir."/rosa/" ) )
{
    // create the directory and log
    mkdir( $gszAppDir."/rosa/", 0777 );
    $oLog->log( LOG_QUIET, "Successfully created ".
                   "directory[".$gszAppDir."/rosa/]." );
}

/* ============================================================================
 * Check for the application's wrapper directory.
 * ========================================================================= */
if ( !is_dir( $gszAppDir."/wrapper/" ) )
{
    // create the directory and log
    mkdir( $gszAppDir."/wrapper/", 0777 );
    $oLog->log( LOG_QUIET, "Successfully created ".
                   "directory[".$gszAppDir."/wrapper/]." );
}

/* ============================================================================
 * Check for the application's logger directory.
 * ========================================================================= */
if ( !is_dir( $gszAppDir."/logger/" ) )
{
    // create the directory and log
    mkdir( $gszAppDir."/logger/", 0777 );
    $oLog->log( LOG_QUIET, "Successfully created ".
                   "directory[".$gszAppDir."/logger/]." );
}

/* ============================================================================
 * Check for the application's images directory.
 * ========================================================================= */
if ( !is_dir( $gszAppDir."/images/" ) )
{
    // create the directory and log
    mkdir( $gszAppDir."/images/", 0777 );
    $oLog->log( LOG_QUIET, "Successfully created ".
                   "directory[".$gszAppDir."/images/]." );
}
 
/* ============================================================================
 * Check for the application's php page.
 * ========================================================================= */
if ( !file_exists( $gszAppDir."/".$http_form_vars["gszAppName"].".php" ) )
{
    // does not exist so copy template
    if ( !copy( TEMPLATES."app_php_file.php", 
                $gszAppDir."/".$http_form_vars["gszAppName"].".php" ) )
    {
        // give error message
        $oLog->error( ERR_CRITICAL, "Unable to create application file".
        "[".$gszAppDir."/".$http_form_vars["gszAppName"].".php].  ".
        "Please ensure that the parent directory exists and is not set ".
        "to read-only." );
        
        // abort all processes
        die( "A critcal error occurred in the last process.  Check the log ".
                            "file[".$gszLogPath."gmapfactory.log] for details" );
    }
    else
    {
        // log success in coping
        $oLog->log( LOG_QUIET, "Successfully created file".
                 "[".$gszAppDir."/".$http_form_vars["gszAppName"].".php]." );        
    }              
}

/* ============================================================================
 * Check for the application's rosa jar file.
 * ========================================================================= */
if ( !file_exists( $gszAppDir."/rosa/rosa.jar" ) )
    copy( TEMPLATES."app_rosa.jar", $gszAppDir."/rosa/rosa.jar" );

/* ============================================================================
 * Check for the application's wrapper files.
 * ========================================================================= */
// map_navigator.php
if ( !file_exists( $gszAppDir."/wrapper/map_navigator.php" ) )
    copy( COMMON."wrapper/map_navigator.php", 
                                    $gszAppDir."/wrapper/map_navigator.php" );  
// map_query.php
if ( !file_exists( $gszAppDir."/wrapper/map_query.php" ) )
    copy( COMMON."wrapper/map_query.php", 
                                        $gszAppDir."/wrapper/map_query.php" );

// map_session.php
if ( !file_exists( $gszAppDir."/wrapper/map_session.php" ) )
    copy( COMMON."wrapper/map_session.php", 
                                       $gszAppDir."/wrapper/map_session.php" );

// utilities.php
if ( !file_exists( $gszAppDir."/wrapper/utilities.php" ) )
    copy( COMMON."wrapper/utilities.php", 
                                        $gszAppDir."/wrapper/utilities.php" );

/* ============================================================================
 * Check for the application's logger files.
 * ========================================================================= */
// error_manager.php
if ( !file_exists( $gszAppDir."/logger/error_manager.php" ) )
    copy( COMMON."logger/error_manager.php", 
                                    $gszAppDir."/logger/error_manager.php" );

// logfile.php
if ( !file_exists( $gszAppDir."/logger/logfile.php" ) )
    copy( COMMON."logger/logfile.php", 
                                           $gszAppDir."/logger/logfile.php" );

// logger.php
if ( !file_exists( $gszAppDir."/logger/logger.php" ) )
    copy( COMMON."logger/logger.php", 
                                            $gszAppDir."/logger/logger.php" );

/* ============================================================================
 * Check for the application's images files.
 * ========================================================================= */
if ( !file_exists( $gszAppDir."/images/icon_eye.gif" ) )
    copy( TEMPLATES."app_icon_eye.gif", $gszAppDir."/images/icon_eye.gif" );                
if ( !file_exists( $gszAppDir."/images/a_pixel.gif" ) )
    copy( TEMPLATES."app_a_pixel.gif", $gszAppDir."/images/a_pixel.gif" );                
if ( !file_exists( $gszAppDir."/images/icon_redraw.gif" ) )
    copy( TEMPLATES."app_icon_redraw.gif",
                                    $gszAppDir."/images/icon_redraw.gif" );                
if ( !file_exists( $gszAppDir."/images/icon_pan_north.gif" ) )
    copy( TEMPLATES."app_icon_pan_north.gif", 
                                $gszAppDir."/images/icon_pan_north.gif" );                
if ( !file_exists( $gszAppDir."/images/icon_pan_east.gif" ) )
    copy( TEMPLATES."app_icon_pan_east.gif", 
                                    $gszAppDir."/images/icon_pan_east.gif" );                
if ( !file_exists( $gszAppDir."/images/icon_pan_south.gif" ) )
    copy( TEMPLATES."app_icon_pan_south.gif", 
                                  $gszAppDir."/images/icon_pan_south.gif" );                
if ( !file_exists( $gszAppDir."/images/icon_pan_west.gif" ) )
    copy( TEMPLATES."app_icon_pan_west.gif", 
                                   $gszAppDir."/images/icon_pan_west.gif" );                
if ( !file_exists( $gszAppDir."/images/icon_zoomin.gif" ) )
    copy( TEMPLATES."app_icon_zoomin.gif", 
                                    $gszAppDir."/images/icon_zoomin.gif" ); 
if ( !file_exists( $gszAppDir."/images/icon_zoomout.gif" ) )
    copy( TEMPLATES."app_icon_zoomout.gif", 
                                    $gszAppDir."/images/icon_zoomout.gif" );                
if ( !file_exists( $gszAppDir."/images/icon_fullextent.gif" ) )
    copy( TEMPLATES."app_icon_fullextent.gif", 
                $gszAppDir."/images/icon_fullextent.gif" );                
if ( !file_exists( $gszAppDir."/images/icon_recentre.gif" ) )
    copy( TEMPLATES."app_icon_recentre.gif", 
                                    $gszAppDir."/images/icon_recentre.gif" );                
if ( !file_exists( $gszAppDir."/images/icon_query.gif" ) )
    copy( TEMPLATES."app_icon_query.gif", 
                                        $gszAppDir."/images/icon_query.gif" );                
if ( !file_exists( $gszAppDir."/images/tool_recentre_1.gif" ) )
    copy( TEMPLATES."app_tool_recentre_1.gif", 
                                $gszAppDir."/images/tool_recentre_1.gif" );                
if ( !file_exists( $gszAppDir."/images/tool_recentre_2.gif" ) )
    copy( TEMPLATES."app_tool_recentre_2.gif", 
                                $gszAppDir."/images/tool_recentre_2.gif" );                
if ( !file_exists( $gszAppDir."/images/tool_rect-query_1.gif" ) )
    copy( TEMPLATES."app_tool_rect-query_1.gif", 
                                $gszAppDir."/images/tool_rect-query_1.gif" );                
if ( !file_exists( $gszAppDir."/images/tool_rect-query_2.gif" ) )
    copy( TEMPLATES."app_tool_rect-query_2.gif", 
                                $gszAppDir."/images/tool_rect-query_2.gif" );                
if ( !file_exists( $gszAppDir."/images/tool_zoomin_1.gif" ) )
    copy( TEMPLATES."app_tool_zoomin_1.gif", 
                                    $gszAppDir."/images/tool_zoomin_1.gif" );                
if ( !file_exists( $gszAppDir."/images/tool_zoomin_2.gif" ) )
    copy( TEMPLATES."app_tool_zoomin_2.gif", 
                                    $gszAppDir."/images/tool_zoomin_2.gif" );                
if ( !file_exists( $gszAppDir."/images/tool_zoomout_1.gif" ) )
    copy( TEMPLATES."app_tool_zoomout_1.gif", 
                                    $gszAppDir."/images/tool_zoomout_1.gif" );                
if ( !file_exists( $gszAppDir."/images/tool_zoomout_2.gif" ) )
    copy( TEMPLATES."app_tool_zoomout_2.gif", 
                                    $gszAppDir."/images/tool_zoomout_2.gif" );                
if ( !file_exists( $gszAppDir."/images/tool_fullex_1.gif" ) )
    copy( TEMPLATES."app_tool_fullex_1.gif", 
                                    $gszAppDir."/images/tool_fullex_1.gif" );                
if ( !file_exists( $gszAppDir."/images/tool_fullex_2.gif" ) )
    copy( TEMPLATES."app_tool_fullex_2.gif", 
                                    $gszAppDir."/images/tool_fullex_2.gif" );                
                
/* ============================================================================
 * Check for the application's drawmap file.
 * ========================================================================= */
if ( !file_exists( $gszAppDir."/drawmap.php" ) )
    copy( TEMPLATES."app_drawmap.php", $gszAppDir."wrapper/drawmap.php" );                

/* ============================================================================
 * Check for the application's query file.
 * ========================================================================= */
if ( !file_exists( $gszAppDir."/query.phtml" ) )
    copy( TEMPLATES."app_query.phtml", $gszAppDir."/query.phtml" );     
                               
/* ============================================================================
 * Check for the application's legend template file.
 * ========================================================================= */
/*if ( !file_exists( $gszAppDir."/legend_template.html" ) )
    copy( TEMPLATES."app_legend_template.html", 
                                        $gszAppDir."/legend_template.html" );*/   
                    
// log end of structure check
$oLog->logFuncEnd( LOG_QUIET, "End structure check." );

?>
